@@ -118,13 +118,14 @@ class vault(object):
     # Fetch the keys from the vault and store it in environment variable
     def fetch_and_store(self, repo_name, env):
         # Store all keys in environment variables
-        secret_repo = self.get_secret(env, repo_name)
+        secret_repo = self.get_secret(env.lower(), repo_name)
         self.parse_and_store_env(secret_repo, env, repo_name)
 
 
 #************************#
 def main():
     pass
+    
 
 if __name__=="__main__":
     main()
